@@ -1,7 +1,23 @@
-# fields, Tools for spatial data
-# Copyright 2015, Institute for Mathematics Applied Geosciences
-# University Corporation for Atmospheric Research
-# Licensed under the GPL -- www.gpl.org/licenses/gpl.html
+# fields  is a package for analysis of spatial data written for
+# the R software environment .
+# Copyright (C) 2018
+# University Corporation for Atmospheric Research (UCAR)
+# Contact: Douglas Nychka, nychka@ucar.edu,
+# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with the R software environment if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# or see http://www.r-project.org/Licenses/GPL-2    
 "image.smooth" <- function(x, wght = NULL, dx = 1, 
     dy = 1, kernel.function = double.exp, theta = 1, grid = NULL, 
     tol = 1e-08, xwidth = NULL, ywidth = NULL, weights = NULL, 
@@ -55,7 +71,7 @@
     if (is.null(wght)) {
         wght <- setup.image.smooth(nrow = m, ncol = n, xwidth = xwidth, 
             ywidth = ywidth, dx = dx, dy = dy, kernel.function = kernel.function, 
-            theta = theta)
+            theta = theta,...)
     }
     M <- nrow(wght$W)
     N <- ncol(wght$W)
