@@ -1,9 +1,22 @@
-# fields, Tools for spatial data
-# Copyright 2004-2011, Institute for Mathematics Applied Geosciences
-# University Corporation for Atmospheric Research
-# Licensed under the GPL -- www.gpl.org/licenses/gpl.html
+ # fields is a package for analysis of spatial data written for
+  # the R software environment .
+  # Copyright (C) 2018
+  # University Corporation for Atmospheric Research (UCAR)
+  # Contact: Douglas Nychka, nychka@ucar.edu,
+  # National Center for Atmospheric Research,
+  # PO Box 3000, Boulder, CO 80307-3000
+  #
+  # This program is free software; you can redistribute it and/or modify
+  # it under the terms of the GNU General Public License as published by
+  # the Free Software Foundation; either version 2 of the License, or
+  # (at your option) any later version.
+  # This program is distributed in the hope that it will be useful,
+  # but WITHOUT ANY WARRANTY; without even the implied warranty of
+  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  # GNU General Public License for more details.
 
-library( fields)
+
+suppressMessages(library(fields))
 options( echo=FALSE)
 test.for.zero.flag<- 1
 
@@ -207,7 +220,7 @@ out.p<-predictSurface( out, grid=gl, extrap=TRUE)
 test.for.zero( ydat, c( out.p$z)[ind], tag="fastTps interp1")
 #image.plot(x,y,matrix( ztrue, nx,ny)- out.p$z) 
 rmse<- sqrt(mean( (ztrue- c( out.p$z))^2)/ mean( (ztrue)^2))
-test.for.zero( rmse,0,tol=.01, relative=FALSE,tag="fastTps interp2")
+test.for.zero( rmse,0,tol=0.02, relative=FALSE,tag="fastTps interp2")
 
 
 ##### test precomputing distance matrices:
